vim.cmd([[
  augroup packer_user_config
    autocmd!
    autocmd BufWritePost plugins.lua source <afile> | PackerCompile
  augroup end
]])

local fn = vim.fn
local install_path = fn.stdpath('data')..'/site/pack/packer/start/packer.nvim'
if fn.empty(fn.glob(install_path)) > 0 then
  packer_bootstrap = fn.system({'git',  'clone', '--depth', '1', 'https://github.com/wbthomason/packer.nvim', install_path})
  vim.cmd [[packadd packer.nvim]]
end

return require('packer').startup({function(use)
  use('ashinkarov/nvim-agda')
  use('lervag/vimtex')
  use('vigoux/LanguageTool.nvim')

  use('wbthomason/packer.nvim')
  use('EdenEast/nightfox.nvim')
  use('folke/which-key.nvim')
  use('numToStr/FTerm.nvim')

  use('brenoprata10/nvim-highlight-colors')

  use('jiaoshijie/undotree')

  use('j-hui/fidget.nvim')

  use('elkowar/yuck.vim')

  use('numToStr/Comment.nvim')
  use('RRethy/vim-illuminate')

  use {
    'nvim-treesitter/nvim-treesitter',
    run = function() require('nvim-treesitter.install').update({ with_sync = true }) end,
  }
  use('https://git.sr.ht/~p00f/nvim-ts-rainbow')
  use('windwp/nvim-autopairs')
  use('windwp/nvim-ts-autotag')

  use {
    'kosayoda/nvim-lightbulb',
    requires = 'antoinemadec/FixCursorHold.nvim',
  }

  use {
    'kyazdani42/nvim-tree.lua',
    requires = {
      'kyazdani42/nvim-web-devicons',
    },
  }

  use {
    'antosha417/nvim-lsp-file-operations',
    requires = {
      { "nvim-lua/plenary.nvim" },
      { "kyazdani42/nvim-tree.lua" },
    }
  }

  use {
    "williamboman/mason.nvim",
    "williamboman/mason-lspconfig.nvim",
  }

  use('simrat39/rust-tools.nvim')

  use('chentoast/marks.nvim')

  use('neovim/nvim-lspconfig')

  use('mfussenegger/nvim-dap')
  use('rcarriga/nvim-dap-ui')
  use('theHamsta/nvim-dap-virtual-text')
  use('nvim-telescope/telescope-dap.nvim')
  use('jayp0521/mason-nvim-dap.nvim')

  use {
    'hrsh7th/cmp-nvim-lsp',
    'hrsh7th/cmp-buffer',
    'hrsh7th/cmp-path',
    'hrsh7th/cmp-cmdline',
    'hrsh7th/cmp-nvim-lsp-signature-help',
    'hrsh7th/nvim-cmp',
    'L3MON4D3/LuaSnip',
    'saadparwaiz1/cmp_luasnip',
  }

  use 'famiu/bufdelete.nvim'

  use {
    'TimUntersberger/neogit',
    'lewis6991/gitsigns.nvim',
  }
  use('nvim-lua/plenary.nvim')

  use('nvim-lualine/lualine.nvim')
  use {
    'akinsho/bufferline.nvim', tag = "v2.*",
    requires = 'kyazdani42/nvim-web-devicons'
  }

  use {
    'nvim-telescope/telescope.nvim', tag = '0.1.0',
    requires = {
      'nvim-lua/plenary.nvim'
    },
  }

  use('nvim-telescope/telescope-ui-select.nvim')

  use('folke/todo-comments.nvim')


  -- Automatically set up your configuration after cloning packer.nvim
  -- Put this at the end after all plugins
  if packer_bootstrap then
    require('packer').sync()
  end
end,
  config = {
    auto_reload_compiled = false, -- Automatically reload the compiled file after creating it.
    display = {
      open_fn = function()
        return require('packer.util').float({ border = 'single' })
      end
    }
  }
})
-- run bootstrap: nvim --headless -c 'autocmd User PackerComplete quitall' -c 'PackerSync'

